@@ -88,9 +88,9 @@
 dd_cs <- function(data     = NULL,
                   niter    = 3000, 
                   nwarmup  = 1000, 
-                  nchain  = 1,
+                  nchain   = 1,
                   ncore    = 1, 
-                  nthin = 1,
+                  nthin    = 1,
                   inits    = "fixed",  
                   indPars  = "mean", 
                   saveDir  = NULL,
@@ -257,9 +257,9 @@ dd_cs <- function(data     = NULL,
                             median(s[, i]), 
                             median(beta[, i]) )
     } else if (indPars=="mode") {
-      allIndPars[i, ] <- c( modeest::mlv(r[, i], method="shorth")[1],
-                            modeest::mlv(s[, i], method="shorth")[1],
-                            modeest::mlv(beta[, i], method="shorth")[1] )
+      allIndPars[i, ] <- c( as.numeric(modeest::mlv(r[, i], method="shorth")[1]),
+                            as.numeric(modeest::mlv(s[, i], method="shorth")[1]),
+                            as.numeric(modeest::mlv(beta[, i], method="shorth")[1]) )
     }
   }
   
