@@ -83,9 +83,9 @@
 gng_m1 <- function(data     = NULL,
                    niter    = 5000, 
                    nwarmup  = 2000, 
-                   nchain  = 1,
+                   nchain   = 1,
                    ncore    = 1, 
-                   nthin = 1,
+                   nthin    = 1,
                    inits    = "random",  
                    indPars  = "mean", 
                    saveDir  = NULL,
@@ -241,9 +241,9 @@ gng_m1 <- function(data     = NULL,
                             median(ep[, i]), 
                             median(rho[, i]) )
     } else if (indPars=="mode") {
-      allIndPars[i, ] <- c( modeest::mlv(xi[, i], method="shorth")[1],
-                            modeest::mlv(ep[, i], method="shorth")[1],
-                            modeest::mlv(rho[, i], method="shorth")[1] )
+      allIndPars[i, ] <- c( as.numeric(modeest::mlv(xi[, i], method="shorth")[1]),
+                            as.numeric(modeest::mlv(ep[, i], method="shorth")[1]),
+                            as.numeric(modeest::mlv(rho[, i], method="shorth")[1]) )
     }
   }
   
